@@ -55,6 +55,7 @@ class TrafficItem(CustomField):
         "gtpu": "gtpv1",
         "gTPuOptionalFields": "gtpv1option",
         "custom": "custom",
+        "vxlan": "vxlan",
     }
 
     _HEADER_TO_TYPE = {
@@ -69,6 +70,7 @@ class TrafficItem(CustomField):
         "gtpv1": "gtpu",
         "gtpv1option": "gTPuOptionalFields",
         "custom": "custom",
+        "vxlan": "vxlan",
     }
 
     _BIT_RATE_UNITS_TYPE = {
@@ -221,7 +223,16 @@ class TrafficItem(CustomField):
         "hop_limit": "ipv6.header.hopLimit",
         "src": "ipv6.header.srcIP",
         "dst": "ipv6.header.dstIP",
-        "order": ["version", "traffic_class", "flow_label", "payload_length"],
+        "order": [
+            "version",
+            "traffic_class",
+            "flow_label",
+            "payload_length",
+            "next_header",
+            "hop_limit",
+            "src",
+            "dst"
+        ],
     }
 
     _TCP = {
@@ -296,6 +307,15 @@ class TrafficItem(CustomField):
         "order": ["length", "data"],
     }
 
+    _VXLAN = {
+        "flags": "vxlan.header.flags",
+        "reserved0": "vxlan.header.reserved",
+        "vni": "vxlan.header.vni",
+        "reserved1": "vxlan.header.reserved8",
+        "order": ["flags", "reserved0", "vni", "reserved1"],
+        "convert_int_to_hex": ["flags", "reserved0", "reserved1"],
+    }
+
     def __init__(self, ixnetworkapi):
         self._api = ixnetworkapi
         self.ixn_config = None
